# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ghome_foyer_api/api.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""

from __future__ import annotations

from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC, 5, 29, 0, "", "ghome_foyer_api/api.proto"
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x19ghome_foyer_api/api.proto\x12\x1dgoogle.internal.home.foyer.v1"\x1d\n\x1bGetAssistantRoutinesRequest"\xf4\x06\n\x1cGetAssistantRoutinesResponse\x12M\n\x02p1\x18\x01 \x03(\x0b\x32\x41.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1\x12M\n\x02p2\x18\x02 \x01(\x0b\x32\x41.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part2\x1a\x8a\x05\n\x05Part1\x12\x14\n\x0croutine_name\x18\x01 \x01(\t\x12\\\n\x08workflow\x18\x03 \x01(\x0b\x32J.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow\x12\x0f\n\x07string4\x18\x04 \x01(\t\x12\x0f\n\x07string5\x18\x05 \x01(\t\x1a\xea\x03\n\x08WorkFlow\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x61\n\x05wf_s1\x18\x02 \x01(\x0b\x32R.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1\x1a\xec\x02\n\x07WF_Sub1\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12q\n\x08wf_s1_s1\x18\x02 \x01(\x0b\x32_.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1\x1a\xdc\x01\n\x0cWF_Sub1_Sub1\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12x\n\x07routine\x18\x02 \x01(\x0b\x32g.google.internal.home.foyer.v1.GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1.Routine\x1a\x41\n\x07Routine\x12\x12\n\nroutine_id\x18\x01 \x01(\t\x12\x0c\n\x04num2\x18\x02 \x01(\r\x12\x14\n\x0croutine_name\x18\x03 \x01(\t\x1a)\n\x05Part2\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x0f\n\x07string3\x18\x03 \x01(\t"4\n\x13GetHomeGraphRequest\x12\x0f\n\x07string1\x18\x03 \x01(\t\x12\x0c\n\x04num2\x18\x04 \x01(\t"\xbc\x37\n\x14GetHomeGraphResponse\x12\x12\n\ntimestamp1\x18\x01 \x01(\x04\x12\x46\n\x04home\x18\x02 \x01(\x0b\x32\x38.google.internal.home.foyer.v1.GetHomeGraphResponse.Home\x12I\n\x06groups\x18\x03 \x03(\x0b\x32\x39.google.internal.home.foyer.v1.GetHomeGraphResponse.Group\x12P\n\nroom_types\x18\x04 \x03(\x0b\x32<.google.internal.home.foyer.v1.GetHomeGraphResponse.RoomType\x12\x0f\n\x07string5\x18\x05 \x01(\t\x12\r\n\x05\x62ool6\x18\x06 \x01(\x08\x12T\n\x0c\x64\x65vice_types\x18\x07 \x03(\x0b\x32>.google.internal.home.foyer.v1.GetHomeGraphResponse.DeviceType\x12V\n\rproject_types\x18\t \x03(\x0b\x32?.google.internal.home.foyer.v1.GetHomeGraphResponse.ProjectType\x12P\n\tmessage11\x18\x0b \x03(\x0b\x32=.google.internal.home.foyer.v1.GetHomeGraphResponse.Message11\x12R\n\x0blinked_apps\x18\x0c \x03(\x0b\x32=.google.internal.home.foyer.v1.GetHomeGraphResponse.LinkedApp\x1a\xc6\'\n\x04Home\x12\x0f\n\x07home_id\x18\x01 \x01(\t\x12\x11\n\thome_name\x18\x02 \x01(\t\x12S\n\x08location\x18\x03 \x01(\x0b\x32\x41.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Location\x12Y\n\x0clinked_users\x18\x04 \x03(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.LinkedUser\x12L\n\x05rooms\x18\x06 \x03(\x0b\x32=.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Room\x12P\n\x07\x64\x65vices\x18\x07 \x03(\x0b\x32?.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device\x12U\n\tmessage11\x18\x0b \x01(\x0b\x32\x42.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message11\x12\x10\n\x08string12\x18\x0c \x01(\t\x12U\n\tmessage13\x18\r \x01(\x0b\x32\x42.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13\x12\x11\n\tmessage14\x18\x0e \x01(\t\x12U\n\tmessage15\x18\x0f \x01(\x0b\x32\x42.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message15\x1a\xd9\x01\n\x08Location\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x62\n\x0b\x63oordinates\x18\x02 \x01(\x0b\x32M.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Location.Coordinates\x12\x12\n\ntimestamp5\x18\x05 \x01(\x04\x12\x10\n\x08timezone\x18\x06 \x01(\t\x1a\x32\n\x0b\x43oordinates\x12\x10\n\x08latitude\x18\x01 \x01(\x01\x12\x11\n\tlongitude\x18\x02 \x01(\x01\x1a#\n\nLinkedUser\x12\x15\n\remail_address\x18\x01 \x01(\t\x1a\x9e\x01\n\x04Room\x12\x0f\n\x07room_id\x18\x01 \x01(\t\x12\x11\n\troom_name\x18\x03 \x01(\t\x12X\n\x08\x63\x61tegory\x18\x04 \x01(\x0b\x32\x46.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Room.Category\x1a\x18\n\x08\x43\x61tegory\x12\x0c\n\x04name\x18\x01 \x01(\t\x1a\xbb\x18\n\x06\x44\x65vice\x12_\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32J.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.DeviceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\t\x12\x0e\n\x06traits\x18\x07 \x03(\t\x12\x0e\n\x06suffix\x18\n \x01(\t\x12\\\n\tmessage12\x18\x0c \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message12\x12\\\n\tmessage15\x18\x0f \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message15\x12Z\n\x08hardware\x18\x11 \x01(\x0b\x32H.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Hardware\x12\\\n\tmessage18\x18\x12 \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message18\x12\x13\n\x0btimestamp19\x18\x13 \x01(\x04\x12\\\n\tmessage20\x18\x14 \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20\x12\\\n\tmessage25\x18\x19 \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message25\x12`\n\x0clinked_users\x18\x1a \x03(\x0b\x32J.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.LinkedUser\x12\x18\n\x10local_auth_token\x18\x1c \x01(\t\x12U\n\x06states\x18\x1d \x03(\x0b\x32\x45.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.State\x12\\\n\tmessage30\x18\x1e \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message30\x12\\\n\tmessage34\x18" \x01(\x0b\x32I.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message34\x12\r\n\x05num37\x18% \x01(\r\x12\x10\n\x08string41\x18) \x01(\t\x12\x10\n\x08string42\x18* \x01(\t\x1a\xc1\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12h\n\nagent_info\x18\x02 \x01(\x0b\x32T.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1aq\n\tMessage12\x12\x0c\n\x04num2\x18\x02 \x01(\r\x12\x0c\n\x04num4\x18\x04 \x01(\r\x12\x0c\n\x04num5\x18\x05 \x01(\r\x12\r\n\x05num37\x18% \x01(\r\x12\r\n\x05num38\x18& \x01(\r\x12\r\n\x05num45\x18- \x01(\r\x12\r\n\x05num46\x18. \x01(\r\x1a\x43\n\tMessage15\x12\x0c\n\x04num1\x18\x01 \x01(\x04\x12\x0c\n\x04num5\x18\x05 \x01(\x04\x12\x0c\n\x04num6\x18\x06 \x01(\x04\x12\x0c\n\x04num7\x18\x07 \x01(\x04\x1a\x19\n\x08Hardware\x12\r\n\x05model\x18\x02 \x01(\t\x1a \n\tMessage18\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x1a\x88\x08\n\tMessage20\x12\x64\n\x08message1\x18\x01 \x03(\x0b\x32R.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1\x1a\x94\x07\n\x08Message1\x12\x0b\n\x03key\x18\x01 \x01(\t\x12g\n\x05value\x18\x02 \x01(\x0b\x32X.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value\x1a\x91\x06\n\x05Value\x12s\n\x08message6\x18\x06 \x01(\x0b\x32\x61.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6\x1a\x92\x05\n\x08Message6\x12|\n\x08message1\x18\x01 \x01(\x0b\x32j.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1\x1a\x87\x04\n\x08Message1\x12\x85\x01\n\x08message5\x18\x05 \x01(\x0b\x32s.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5\x1a\xf2\x02\n\x08Message5\x12\x8e\x01\n\x08message1\x18\x01 \x03(\x0b\x32|.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1\x1a\xd4\x01\n\x08Message1\x12\x12\n\ncapability\x18\x01 \x01(\t\x12\x98\x01\n\x08message2\x18\x02 \x01(\x0b\x32\x85\x01.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1.Message2\x1a\x19\n\x08Message2\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x1a)\n\tMessage25\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x12\r\n\x05\x62ool2\x18\x02 \x01(\x08\x1a#\n\nLinkedUser\x12\x15\n\remail_address\x18\x01 \x01(\t\x1a$\n\x05State\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c\x1a\xa6\x02\n\tMessage30\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x64\n\x08message2\x18\x02 \x01(\x0b\x32R.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message30.Message2\x1a\xa5\x01\n\x08Message2\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12m\n\x08message2\x18\x02 \x01(\x0b\x32[.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Device.Message30.Message2.Message2\x1a\x19\n\x08Message2\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x1a\x1a\n\tMessage34\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x1a\x1a\n\tMessage11\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x1a\xe4\x03\n\tMessage13\x12]\n\x08message1\x18\x01 \x01(\x0b\x32K.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13.Message1\x12\x14\n\x0c\x64uo_call_url\x18\x02 \x01(\t\x12\x18\n\x10\x64uo_phone_number\x18\x03 \x01(\t\x1a\xc7\x02\n\x08Message1\x12k\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32V.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo\x1a\xcd\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12t\n\nagent_info\x18\x02 \x01(\x0b\x32`.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1a\xbc\x02\n\tMessage15\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x12\x0f\n\x07string2\x18\x02 \x01(\t\x12]\n\x08message3\x18\x03 \x03(\x0b\x32K.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message15.Message3\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x1a\xa0\x01\n\x08Message3\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x66\n\x08message2\x18\x02 \x01(\x0b\x32T.google.internal.home.foyer.v1.GetHomeGraphResponse.Home.Message15.Message3.Message2\x1a\x1b\n\x08Message2\x12\x0f\n\x07string1\x18\x01 \x01(\t\x1a\x87\x08\n\x05Group\x12Y\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32\x44.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.DeviceInfo\x12\x12\n\ngroup_nmae\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x06 \x01(\t\x12\x0e\n\x06traits\x18\x07 \x01(\t\x12\x0e\n\x06suffix\x18\n \x01(\t\x12V\n\tmessage12\x18\x0c \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message12\x12V\n\tmessage15\x18\x0f \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message15\x12V\n\tmessage17\x18\x11 \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message17\x12V\n\tmessage18\x18\x12 \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message18\x12\x13\n\x0btimestamp19\x18\x13 \x01(\x04\x12V\n\tmessage34\x18" \x01(\x0b\x32\x43.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.Message34\x1a\xa8\x01\n\nDeviceInfo\x12\x62\n\nagent_info\x18\x02 \x01(\x0b\x32N.google.internal.home.foyer.v1.GetHomeGraphResponse.Group.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1aI\n\tMessage12\x12\r\n\x05\x62ool3\x18\x03 \x01(\x08\x12\r\n\x05\x62ool4\x18\x04 \x01(\x08\x12\x0e\n\x06\x62ool37\x18% \x01(\x08\x12\x0e\n\x06\x62ool38\x18& \x01(\x08\x1a\x38\n\tMessage15\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x0c\n\x04num5\x18\x05 \x01(\x04\x12\x0c\n\x04num6\x18\x06 \x01(\r\x1a \n\tMessage17\x12\x13\n\x0bgroup_model\x18\x02 \x01(\t\x1a\x1f\n\tMessage18\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x1a\x1a\n\tMessage34\x12\r\n\x05\x62ool1\x18\x01 \x01(\x08\x1a&\n\x08RoomType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a(\n\nDeviceType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a)\n\x0bProjectType\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x8d\x01\n\tMessage11\x12\x0c\n\x04name\x18\x01 \x01(\t\x12X\n\x08message2\x18\x02 \x01(\x0b\x32\x46.google.internal.home.foyer.v1.GetHomeGraphResponse.Message11.Message2\x1a\x18\n\x08Message2\x12\x0c\n\x04num2\x18\x02 \x01(\r\x1aW\n\tLinkedApp\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x0f\n\x07string2\x18\x02 \x01(\t\x12\x0c\n\x04num3\x18\x03 \x01(\r\x12\x0c\n\x04num4\x18\x04 \x01(\r\x12\x0c\n\x04num5\x18\x05 \x01(\r"\xdb\x02\n!GetAssistantDeviceSettingsRequest\x12`\n\x0b\x64\x65vice_info\x18\x01 \x01(\x0b\x32K.google.internal.home.foyer.v1.GetAssistantDeviceSettingsRequest.DeviceInfo\x12\x0f\n\x07string2\x18\x02 \x01(\t\x1a\xc2\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12i\n\nagent_info\x18\x02 \x01(\x0b\x32U.google.internal.home.foyer.v1.GetAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t"\xe6\x01\n"GetAssistantDeviceSettingsResponse\x12\\\n\x08message1\x18\x01 \x01(\x0b\x32J.google.internal.home.foyer.v1.GetAssistantDeviceSettingsResponse.Message1\x1a\x62\n\x08Message1\x12\x0c\n\x04num1\x18\x01 \x01(\r\x12\x0c\n\x04num2\x18\x02 \x01(\r\x12\x0c\n\x04num4\x18\x04 \x01(\r\x12\x0c\n\x04num5\x18\x05 \x01(\r\x12\x0c\n\x04num6\x18\x06 \x01(\r\x12\x10\n\x08string10\x18\n \x01(\t"\xa3\x05\n$UpdateAssistantDeviceSettingsRequest\x12\x0f\n\x07string1\x18\x01 \x01(\t\x12\x63\n\x0b\x64\x65vice_info\x18\x02 \x01(\x0b\x32N.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.DeviceInfo\x12\x63\n\x0bupdate_data\x18\x03 \x01(\x0b\x32N.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.UpdateData\x1a\xc5\x01\n\nDeviceInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\t\x12l\n\nagent_info\x18\x02 \x01(\x0b\x32X.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo\x1a\x36\n\tAgentInfo\x12\x16\n\x0e\x61pi_project_id\x18\x01 \x01(\t\x12\x11\n\tunique_id\x18\x02 \x01(\t\x1a\xd7\x01\n\nUpdateData\x12i\n\x08message1\x18\x01 \x01(\x0b\x32W.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest.UpdateData.Message1\x1a^\n\x08Message1\x12\x1f\n\x17youtube_restricted_mode\x18\x04 \x01(\r\x12!\n\x19youtube_tv_content_filter\x18\x05 \x01(\r\x12\x0e\n\x06locale\x18\n \x01(\t"8\n%UpdateAssistantDeviceSettingsResponse\x12\x0f\n\x07string1\x18\x01 \x01(\t2\xa8\x01\n\x12HomeControlService\x12\x91\x01\n\x14GetAssistantRoutines\x12:.google.internal.home.foyer.v1.GetAssistantRoutinesRequest\x1a;.google.internal.home.foyer.v1.GetAssistantRoutinesResponse0\x01\x32\x8c\x01\n\x11StructuresService\x12w\n\x0cGetHomeGraph\x12\x32.google.internal.home.foyer.v1.GetHomeGraphRequest\x1a\x33.google.internal.home.foyer.v1.GetHomeGraphResponse2\xe9\x02\n\x12HomeDevicesService\x12\xa3\x01\n\x1aGetAssistantDeviceSettings\x12@.google.internal.home.foyer.v1.GetAssistantDeviceSettingsRequest\x1a\x41.google.internal.home.foyer.v1.GetAssistantDeviceSettingsResponse0\x01\x12\xac\x01\n\x1dUpdateAssistantDeviceSettings\x12\x43.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsRequest\x1a\x44.google.internal.home.foyer.v1.UpdateAssistantDeviceSettingsResponse0\x01\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "ghome_foyer_api.api_pb2", _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    DESCRIPTOR._loaded_options = None
    _globals["_GETASSISTANTROUTINESREQUEST"]._serialized_start = 60
    _globals["_GETASSISTANTROUTINESREQUEST"]._serialized_end = 89
    _globals["_GETASSISTANTROUTINESRESPONSE"]._serialized_start = 92
    _globals["_GETASSISTANTROUTINESRESPONSE"]._serialized_end = 976
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1"]._serialized_start = 283
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1"]._serialized_end = 933
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW"]._serialized_start = 443
    _globals["_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW"]._serialized_end = 933
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1"
    ]._serialized_start = 569
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1"
    ]._serialized_end = 933
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1"
    ]._serialized_start = 713
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1"
    ]._serialized_end = 933
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1_ROUTINE"
    ]._serialized_start = 868
    _globals[
        "_GETASSISTANTROUTINESRESPONSE_PART1_WORKFLOW_WF_SUB1_WF_SUB1_SUB1_ROUTINE"
    ]._serialized_end = 933
    _globals["_GETASSISTANTROUTINESRESPONSE_PART2"]._serialized_start = 935
    _globals["_GETASSISTANTROUTINESRESPONSE_PART2"]._serialized_end = 976
    _globals["_GETHOMEGRAPHREQUEST"]._serialized_start = 978
    _globals["_GETHOMEGRAPHREQUEST"]._serialized_end = 1030
    _globals["_GETHOMEGRAPHRESPONSE"]._serialized_start = 1033
    _globals["_GETHOMEGRAPHRESPONSE"]._serialized_end = 8133
    _globals["_GETHOMEGRAPHRESPONSE_HOME"]._serialized_start = 1679
    _globals["_GETHOMEGRAPHRESPONSE_HOME"]._serialized_end = 6741
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION"]._serialized_start = 2358
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION"]._serialized_end = 2575
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION_COORDINATES"]._serialized_start = 2525
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LOCATION_COORDINATES"]._serialized_end = 2575
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LINKEDUSER"]._serialized_start = 2577
    _globals["_GETHOMEGRAPHRESPONSE_HOME_LINKEDUSER"]._serialized_end = 2612
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM"]._serialized_start = 2615
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM"]._serialized_end = 2773
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM_CATEGORY"]._serialized_start = 2749
    _globals["_GETHOMEGRAPHRESPONSE_HOME_ROOM_CATEGORY"]._serialized_end = 2773
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE"]._serialized_start = 2776
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE"]._serialized_end = 5907
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO"]._serialized_start = 3991
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO"]._serialized_end = 4184
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE12"]._serialized_start = 4186
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE12"]._serialized_end = 4299
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE15"]._serialized_start = 4301
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE15"]._serialized_end = 4368
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_HARDWARE"]._serialized_start = 4370
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_HARDWARE"]._serialized_end = 4395
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE18"]._serialized_start = 4397
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE18"]._serialized_end = 4429
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20"]._serialized_start = 4432
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20"]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1"
    ]._serialized_start = 4548
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE"
    ]._serialized_start = 4679
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6"
    ]._serialized_start = 4806
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1"
    ]._serialized_start = 4945
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5"
    ]._serialized_start = 5094
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1"
    ]._serialized_start = 5252
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1"
    ]._serialized_end = 5464
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1_MESSAGE2"
    ]._serialized_start = 5439
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE20_MESSAGE1_VALUE_MESSAGE6_MESSAGE1_MESSAGE5_MESSAGE1_MESSAGE2"
    ]._serialized_end = 5464
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE25"]._serialized_start = 5466
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE25"]._serialized_end = 5507
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_LINKEDUSER"]._serialized_start = 2577
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_LINKEDUSER"]._serialized_end = 2612
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_STATE"]._serialized_start = 5546
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_STATE"]._serialized_end = 5582
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30"]._serialized_start = 5585
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30"]._serialized_end = 5879
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2"
    ]._serialized_start = 5714
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2"
    ]._serialized_end = 5879
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2_MESSAGE2"
    ]._serialized_start = 5439
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE30_MESSAGE2_MESSAGE2"
    ]._serialized_end = 5464
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE34"]._serialized_start = 5881
    _globals["_GETHOMEGRAPHRESPONSE_HOME_DEVICE_MESSAGE34"]._serialized_end = 5907
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE11"]._serialized_start = 5909
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE11"]._serialized_end = 5935
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13"]._serialized_start = 5938
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13"]._serialized_end = 6422
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1"]._serialized_start = 6095
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1"]._serialized_end = 6422
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO"
    ]._serialized_start = 6217
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO"
    ]._serialized_end = 6422
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE13_MESSAGE1_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15"]._serialized_start = 6425
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15"]._serialized_end = 6741
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3"]._serialized_start = 6581
    _globals["_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3"]._serialized_end = 6741
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3_MESSAGE2"
    ]._serialized_start = 5714
    _globals[
        "_GETHOMEGRAPHRESPONSE_HOME_MESSAGE15_MESSAGE3_MESSAGE2"
    ]._serialized_end = 5741
    _globals["_GETHOMEGRAPHRESPONSE_GROUP"]._serialized_start = 6744
    _globals["_GETHOMEGRAPHRESPONSE_GROUP"]._serialized_end = 7775
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO"]._serialized_start = 7379
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO"]._serialized_end = 7547
    _globals[
        "_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_DEVICEINFO_AGENTINFO"]._serialized_end = 4184
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE12"]._serialized_start = 7549
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE12"]._serialized_end = 7622
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE15"]._serialized_start = 7624
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE15"]._serialized_end = 7680
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE17"]._serialized_start = 7682
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE17"]._serialized_end = 7714
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE18"]._serialized_start = 7716
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE18"]._serialized_end = 7747
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE34"]._serialized_start = 5881
    _globals["_GETHOMEGRAPHRESPONSE_GROUP_MESSAGE34"]._serialized_end = 5907
    _globals["_GETHOMEGRAPHRESPONSE_ROOMTYPE"]._serialized_start = 7777
    _globals["_GETHOMEGRAPHRESPONSE_ROOMTYPE"]._serialized_end = 7815
    _globals["_GETHOMEGRAPHRESPONSE_DEVICETYPE"]._serialized_start = 7817
    _globals["_GETHOMEGRAPHRESPONSE_DEVICETYPE"]._serialized_end = 7857
    _globals["_GETHOMEGRAPHRESPONSE_PROJECTTYPE"]._serialized_start = 7859
    _globals["_GETHOMEGRAPHRESPONSE_PROJECTTYPE"]._serialized_end = 7900
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11"]._serialized_start = 7903
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11"]._serialized_end = 8044
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11_MESSAGE2"]._serialized_start = 8020
    _globals["_GETHOMEGRAPHRESPONSE_MESSAGE11_MESSAGE2"]._serialized_end = 8044
    _globals["_GETHOMEGRAPHRESPONSE_LINKEDAPP"]._serialized_start = 8046
    _globals["_GETHOMEGRAPHRESPONSE_LINKEDAPP"]._serialized_end = 8133
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST"]._serialized_start = 8136
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST"]._serialized_end = 8483
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"]._serialized_start = 8289
    _globals["_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"]._serialized_end = 8483
    _globals[
        "_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_GETASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE"]._serialized_start = 8486
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE"]._serialized_end = 8716
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE_MESSAGE1"]._serialized_start = 8618
    _globals["_GETASSISTANTDEVICESETTINGSRESPONSE_MESSAGE1"]._serialized_end = 8716
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST"]._serialized_start = 8719
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST"]._serialized_end = 9394
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"
    ]._serialized_start = 8979
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO"]._serialized_end = 9176
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_start = 4130
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_DEVICEINFO_AGENTINFO"
    ]._serialized_end = 4184
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA"
    ]._serialized_start = 9179
    _globals["_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA"]._serialized_end = 9394
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA_MESSAGE1"
    ]._serialized_start = 9300
    _globals[
        "_UPDATEASSISTANTDEVICESETTINGSREQUEST_UPDATEDATA_MESSAGE1"
    ]._serialized_end = 9394
    _globals["_UPDATEASSISTANTDEVICESETTINGSRESPONSE"]._serialized_start = 9396
    _globals["_UPDATEASSISTANTDEVICESETTINGSRESPONSE"]._serialized_end = 9452
    _globals["_HOMECONTROLSERVICE"]._serialized_start = 9455
    _globals["_HOMECONTROLSERVICE"]._serialized_end = 9623
    _globals["_STRUCTURESSERVICE"]._serialized_start = 9626
    _globals["_STRUCTURESSERVICE"]._serialized_end = 9766
    _globals["_HOMEDEVICESSERVICE"]._serialized_start = 9769
    _globals["_HOMEDEVICESSERVICE"]._serialized_end = 10130
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
This file contains the following services:

HomeControlService
  - GetAssistantRoutines

StructuresService
  - GetHomeGraph

HomeDevicesService
  - GetAssistantDeviceSettings
"""

import abc
import collections.abc
import ghome_foyer_api.api_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class HomeControlServiceStub:
    """Home Control Service"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetAssistantRoutines: grpc.UnaryStreamMultiCallable[
        ghome_foyer_api.api_pb2.GetAssistantRoutinesRequest,
        ghome_foyer_api.api_pb2.GetAssistantRoutinesResponse,
    ]

class HomeControlServiceAsyncStub:
    """Home Control Service"""

    GetAssistantRoutines: grpc.aio.UnaryStreamMultiCallable[
        ghome_foyer_api.api_pb2.GetAssistantRoutinesRequest,
        ghome_foyer_api.api_pb2.GetAssistantRoutinesResponse,
    ]

class HomeControlServiceServicer(metaclass=abc.ABCMeta):
    """Home Control Service"""

    @abc.abstractmethod
    def GetAssistantRoutines(
        self,
        request: ghome_foyer_api.api_pb2.GetAssistantRoutinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[ghome_foyer_api.api_pb2.GetAssistantRoutinesResponse], collections.abc.AsyncIterator[ghome_foyer_api.api_pb2.GetAssistantRoutinesResponse]]: ...

def add_HomeControlServiceServicer_to_server(servicer: HomeControlServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class StructuresServiceStub:
    """Structure Service"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetHomeGraph: grpc.UnaryUnaryMultiCallable[
        ghome_foyer_api.api_pb2.GetHomeGraphRequest,
        ghome_foyer_api.api_pb2.GetHomeGraphResponse,
    ]

class StructuresServiceAsyncStub:
    """Structure Service"""

    GetHomeGraph: grpc.aio.UnaryUnaryMultiCallable[
        ghome_foyer_api.api_pb2.GetHomeGraphRequest,
        ghome_foyer_api.api_pb2.GetHomeGraphResponse,
    ]

class StructuresServiceServicer(metaclass=abc.ABCMeta):
    """Structure Service"""

    @abc.abstractmethod
    def GetHomeGraph(
        self,
        request: ghome_foyer_api.api_pb2.GetHomeGraphRequest,
        context: _ServicerContext,
    ) -> typing.Union[ghome_foyer_api.api_pb2.GetHomeGraphResponse, collections.abc.Awaitable[ghome_foyer_api.api_pb2.GetHomeGraphResponse]]: ...

def add_StructuresServiceServicer_to_server(servicer: StructuresServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...

class HomeDevicesServiceStub:
    """Home Devices Service"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    GetAssistantDeviceSettings: grpc.UnaryStreamMultiCallable[
        ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsRequest,
        ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsResponse,
    ]

    UpdateAssistantDeviceSettings: grpc.UnaryStreamMultiCallable[
        ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsRequest,
        ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsResponse,
    ]

class HomeDevicesServiceAsyncStub:
    """Home Devices Service"""

    GetAssistantDeviceSettings: grpc.aio.UnaryStreamMultiCallable[
        ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsRequest,
        ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsResponse,
    ]

    UpdateAssistantDeviceSettings: grpc.aio.UnaryStreamMultiCallable[
        ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsRequest,
        ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsResponse,
    ]

class HomeDevicesServiceServicer(metaclass=abc.ABCMeta):
    """Home Devices Service"""

    @abc.abstractmethod
    def GetAssistantDeviceSettings(
        self,
        request: ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsResponse], collections.abc.AsyncIterator[ghome_foyer_api.api_pb2.GetAssistantDeviceSettingsResponse]]: ...

    @abc.abstractmethod
    def UpdateAssistantDeviceSettings(
        self,
        request: ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsResponse], collections.abc.AsyncIterator[ghome_foyer_api.api_pb2.UpdateAssistantDeviceSettingsResponse]]: ...

def add_HomeDevicesServiceServicer_to_server(servicer: HomeDevicesServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
This file contains the following services:

HomeControlService
  - GetAssistantRoutines

StructuresService
  - GetHomeGraph

HomeDevicesService
  - GetAssistantDeviceSettings
"""

from builtins import (
    bool,
    bytes,
    float,
    int,
    str,
)
from collections.abc import (
    Iterable,
)
from google.protobuf.descriptor import (
    Descriptor,
    FileDescriptor,
)
from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer,
    RepeatedScalarFieldContainer,
)
from google.protobuf.message import (
    Message,
)
from typing import (
    Literal,
    final,
)

DESCRIPTOR: FileDescriptor

@final
class GetAssistantRoutinesRequest(Message):
    DESCRIPTOR: Descriptor

    def __init__(
        self,
    ) -> None: ...

@final
class GetAssistantRoutinesResponse(Message):
    DESCRIPTOR: Descriptor

    @final
    class Part1(Message):
        DESCRIPTOR: Descriptor

        @final
        class WorkFlow(Message):
            DESCRIPTOR: Descriptor

            @final
            class WF_Sub1(Message):
                DESCRIPTOR: Descriptor

                @final
                class WF_Sub1_Sub1(Message):
                    DESCRIPTOR: Descriptor

                    @final
                    class Routine(Message):
                        DESCRIPTOR: Descriptor

                        ROUTINE_ID_FIELD_NUMBER: int
                        NUM2_FIELD_NUMBER: int
                        ROUTINE_NAME_FIELD_NUMBER: int
                        routine_id: str
                        num2: int
                        routine_name: str
                        def __init__(
                            self,
                            *,
                            routine_id: str = ...,
                            num2: int = ...,
                            routine_name: str = ...,
                        ) -> None: ...
                        def ClearField(self, field_name: Literal["num2", b"num2", "routine_id", b"routine_id", "routine_name", b"routine_name"]) -> None: ...

                    STRING1_FIELD_NUMBER: int
                    ROUTINE_FIELD_NUMBER: int
                    string1: str
                    @property
                    def routine(self) -> GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1.Routine: ...
                    def __init__(
                        self,
                        *,
                        string1: str = ...,
                        routine: GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1.Routine | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: Literal["routine", b"routine"]) -> bool: ...
                    def ClearField(self, field_name: Literal["routine", b"routine", "string1", b"string1"]) -> None: ...

                STRING1_FIELD_NUMBER: int
                WF_S1_S1_FIELD_NUMBER: int
                string1: str
                @property
                def wf_s1_s1(self) -> GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1: ...
                def __init__(
                    self,
                    *,
                    string1: str = ...,
                    wf_s1_s1: GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1.WF_Sub1_Sub1 | None = ...,
                ) -> None: ...
                def HasField(self, field_name: Literal["wf_s1_s1", b"wf_s1_s1"]) -> bool: ...
                def ClearField(self, field_name: Literal["string1", b"string1", "wf_s1_s1", b"wf_s1_s1"]) -> None: ...

            TYPE_FIELD_NUMBER: int
            WF_S1_FIELD_NUMBER: int
            type: str
            @property
            def wf_s1(self) -> GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1: ...
            def __init__(
                self,
                *,
                type: str = ...,
                wf_s1: GetAssistantRoutinesResponse.Part1.WorkFlow.WF_Sub1 | None = ...,
            ) -> None: ...
            def HasField(self, field_name: Literal["wf_s1", b"wf_s1"]) -> bool: ...
            def ClearField(self, field_name: Literal["type", b"type", "wf_s1", b"wf_s1"]) -> None: ...

        ROUTINE_NAME_FIELD_NUMBER: int
        WORKFLOW_FIELD_NUMBER: int
        STRING4_FIELD_NUMBER: int
        STRING5_FIELD_NUMBER: int
        routine_name: str
        string4: str
        string5: str
        @property
        def workflow(self) -> GetAssistantRoutinesResponse.Part1.WorkFlow: ...
        def __init__(
            self,
            *,
            routine_name: str = ...,
            workflow: GetAssistantRoutinesResponse.Part1.WorkFlow | None = ...,
            string4: str = ...,
            string5: str = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["workflow", b"workflow"]) -> bool: ...
        def ClearField(self, field_name: Literal["routine_name", b"routine_name", "string4", b"string4", "string5", b"string5", "workflow", b"workflow"]) -> None: ...

    @final
    class Part2(Message):
        DESCRIPTOR: Descriptor

        STRING1_FIELD_NUMBER: int
        STRING3_FIELD_NUMBER: int
        string1: str
        string3: str
        def __init__(
            self,
            *,
            string1: str = ...,
            string3: str = ...,
        ) -> None: ...
        def ClearField(self, field_name: Literal["string1", b"string1", "string3", b"string3"]) -> None: ...

    P1_FIELD_NUMBER: int
    P2_FIELD_NUMBER: int
    @property
    def p1(self) -> RepeatedCompositeFieldContainer[GetAssistantRoutinesResponse.Part1]: ...
    @property
    def p2(self) -> GetAssistantRoutinesResponse.Part2: ...
    def __init__(
        self,
        *,
        p1: Iterable[GetAssistantRoutinesResponse.Part1] | None = ...,
        p2: GetAssistantRoutinesResponse.Part2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["p2", b"p2"]) -> bool: ...
    def ClearField(self, field_name: Literal["p1", b"p1", "p2", b"p2"]) -> None: ...

@final
class GetHomeGraphRequest(Message):
    DESCRIPTOR: Descriptor

    STRING1_FIELD_NUMBER: int
    NUM2_FIELD_NUMBER: int
    string1: str
    num2: str
    def __init__(
        self,
        *,
        string1: str = ...,
        num2: str = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["num2", b"num2", "string1", b"string1"]) -> None: ...

@final
class GetHomeGraphResponse(Message):
    DESCRIPTOR: Descriptor

    @final
    class Home(Message):
        DESCRIPTOR: Descriptor

        @final
        class Location(Message):
            DESCRIPTOR: Descriptor

            @final
            class Coordinates(Message):
                DESCRIPTOR: Descriptor

                LATITUDE_FIELD_NUMBER: int
                LONGITUDE_FIELD_NUMBER: int
                latitude: float
                longitude: float
                def __init__(
                    self,
                    *,
                    latitude: float = ...,
                    longitude: float = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["latitude", b"latitude", "longitude", b"longitude"]) -> None: ...

            ADDRESS_FIELD_NUMBER: int
            COORDINATES_FIELD_NUMBER: int
            TIMESTAMP5_FIELD_NUMBER: int
            TIMEZONE_FIELD_NUMBER: int
            address: str
            timestamp5: int
            timezone: str
            @property
            def coordinates(self) -> GetHomeGraphResponse.Home.Location.Coordinates: ...
            def __init__(
                self,
                *,
                address: str = ...,
                coordinates: GetHomeGraphResponse.Home.Location.Coordinates | None = ...,
                timestamp5: int = ...,
                timezone: str = ...,
            ) -> None: ...
            def HasField(self, field_name: Literal["coordinates", b"coordinates"]) -> bool: ...
            def ClearField(self, field_name: Literal["address", b"address", "coordinates", b"coordinates", "timestamp5", b"timestamp5", "timezone", b"timezone"]) -> None: ...

        @final
        class LinkedUser(Message):
            DESCRIPTOR: Descriptor

            EMAIL_ADDRESS_FIELD_NUMBER: int
            email_address: str
            def __init__(
                self,
                *,
                email_address: str = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["email_address", b"email_address"]) -> None: ...

        @final
        class Room(Message):
            DESCRIPTOR: Descriptor

            @final
            class Category(Message):
                DESCRIPTOR: Descriptor

                NAME_FIELD_NUMBER: int
                name: str
                def __init__(
                    self,
                    *,
                    name: str = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["name", b"name"]) -> None: ...

            ROOM_ID_FIELD_NUMBER: int
            ROOM_NAME_FIELD_NUMBER: int
            CATEGORY_FIELD_NUMBER: int
            room_id: str
            room_name: str
            @property
            def category(self) -> GetHomeGraphResponse.Home.Room.Category: ...
            def __init__(
                self,
                *,
                room_id: str = ...,
                room_name: str = ...,
                category: GetHomeGraphResponse.Home.Room.Category | None = ...,
            ) -> None: ...
            def HasField(self, field_name: Literal["category", b"category"]) -> bool: ...
            def ClearField(self, field_name: Literal["category", b"category", "room_id", b"room_id", "room_name", b"room_name"]) -> None: ...

        @final
        class Device(Message):
            DESCRIPTOR: Descriptor

            @final
            class DeviceInfo(Message):
                DESCRIPTOR: Descriptor

                @final
                class AgentInfo(Message):
                    DESCRIPTOR: Descriptor

                    API_PROJECT_ID_FIELD_NUMBER: int
                    UNIQUE_ID_FIELD_NUMBER: int
                    api_project_id: str
                    unique_id: str
                    def __init__(
                        self,
                        *,
                        api_project_id: str = ...,
                        unique_id: str = ...,
                    ) -> None: ...
                    def ClearField(self, field_name: Literal["api_project_id", b"api_project_id", "unique_id", b"unique_id"]) -> None: ...

                DEVICE_ID_FIELD_NUMBER: int
                AGENT_INFO_FIELD_NUMBER: int
                device_id: str
                @property
                def agent_info(self) -> GetHomeGraphResponse.Home.Device.DeviceInfo.AgentInfo: ...
                def __init__(
                    self,
                    *,
                    device_id: str = ...,
                    agent_info: GetHomeGraphResponse.Home.Device.DeviceInfo.AgentInfo | None = ...,
                ) -> None: ...
                def HasField(self, field_name: Literal["agent_info", b"agent_info"]) -> bool: ...
                def ClearField(self, field_name: Literal["agent_info", b"agent_info", "device_id", b"device_id"]) -> None: ...

            @final
            class Message12(Message):
                DESCRIPTOR: Descriptor

                NUM2_FIELD_NUMBER: int
                NUM4_FIELD_NUMBER: int
                NUM5_FIELD_NUMBER: int
                NUM37_FIELD_NUMBER: int
                NUM38_FIELD_NUMBER: int
                NUM45_FIELD_NUMBER: int
                NUM46_FIELD_NUMBER: int
                num2: int
                num4: int
                num5: int
                num37: int
                num38: int
                num45: int
                num46: int
                def __init__(
                    self,
                    *,
                    num2: int = ...,
                    num4: int = ...,
                    num5: int = ...,
                    num37: int = ...,
                    num38: int = ...,
                    num45: int = ...,
                    num46: int = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["num2", b"num2", "num37", b"num37", "num38", b"num38", "num4", b"num4", "num45", b"num45", "num46", b"num46", "num5", b"num5"]) -> None: ...

            @final
            class Message15(Message):
                DESCRIPTOR: Descriptor

                NUM1_FIELD_NUMBER: int
                NUM5_FIELD_NUMBER: int
                NUM6_FIELD_NUMBER: int
                NUM7_FIELD_NUMBER: int
                num1: int
                num5: int
                num6: int
                num7: int
                def __init__(
                    self,
                    *,
                    num1: int = ...,
                    num5: int = ...,
                    num6: int = ...,
                    num7: int = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["num1", b"num1", "num5", b"num5", "num6", b"num6", "num7", b"num7"]) -> None: ...

            @final
            class Hardware(Message):
                DESCRIPTOR: Descriptor

                MODEL_FIELD_NUMBER: int
                model: str
                def __init__(
                    self,
                    *,
                    model: str = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["model", b"model"]) -> None: ...

            @final
            class Message18(Message):
                DESCRIPTOR: Descriptor

                DEVICE_NAME_FIELD_NUMBER: int
                device_name: str
                def __init__(
                    self,
                    *,
                    device_name: str = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["device_name", b"device_name"]) -> None: ...

            @final
            class Message20(Message):
                DESCRIPTOR: Descriptor

                @final
                class Message1(Message):
                    DESCRIPTOR: Descriptor

                    @final
                    class Value(Message):
                        DESCRIPTOR: Descriptor

                        @final
                        class Message6(Message):
                            DESCRIPTOR: Descriptor

                            @final
                            class Message1(Message):
                                DESCRIPTOR: Descriptor

                                @final
                                class Message5(Message):
                                    DESCRIPTOR: Descriptor

                                    @final
                                    class Message1(Message):
                                        DESCRIPTOR: Descriptor

                                        @final
                                        class Message2(Message):
                                            DESCRIPTOR: Descriptor

                                            BOOL4_FIELD_NUMBER: int
                                            bool4: bool
                                            def __init__(
                                                self,
                                                *,
                                                bool4: bool = ...,
                                            ) -> None: ...
                                            def ClearField(self, field_name: Literal["bool4", b"bool4"]) -> None: ...

                                        CAPABILITY_FIELD_NUMBER: int
                                        MESSAGE2_FIELD_NUMBER: int
                                        capability: str
                                        @property
                                        def message2(self) -> GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1.Message2: ...
                                        def __init__(
                                            self,
                                            *,
                                            capability: str = ...,
                                            message2: GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1.Message2 | None = ...,
                                        ) -> None: ...
                                        def HasField(self, field_name: Literal["message2", b"message2"]) -> bool: ...
                                        def ClearField(self, field_name: Literal["capability", b"capability", "message2", b"message2"]) -> None: ...

                                    MESSAGE1_FIELD_NUMBER: int
                                    @property
                                    def message1(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1]: ...
                                    def __init__(
                                        self,
                                        *,
                                        message1: Iterable[GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5.Message1] | None = ...,
                                    ) -> None: ...
                                    def ClearField(self, field_name: Literal["message1", b"message1"]) -> None: ...

                                MESSAGE5_FIELD_NUMBER: int
                                @property
                                def message5(self) -> GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5: ...
                                def __init__(
                                    self,
                                    *,
                                    message5: GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1.Message5 | None = ...,
                                ) -> None: ...
                                def HasField(self, field_name: Literal["message5", b"message5"]) -> bool: ...
                                def ClearField(self, field_name: Literal["message5", b"message5"]) -> None: ...

                            MESSAGE1_FIELD_NUMBER: int
                            @property
                            def message1(self) -> GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1: ...
                            def __init__(
                                self,
                                *,
                                message1: GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6.Message1 | None = ...,
                            ) -> None: ...
                            def HasField(self, field_name: Literal["message1", b"message1"]) -> bool: ...
                            def ClearField(self, field_name: Literal["message1", b"message1"]) -> None: ...

                        MESSAGE6_FIELD_NUMBER: int
                        @property
                        def message6(self) -> GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6: ...
                        def __init__(
                            self,
                            *,
                            message6: GetHomeGraphResponse.Home.Device.Message20.Message1.Value.Message6 | None = ...,
                        ) -> None: ...
                        def HasField(self, field_name: Literal["message6", b"message6"]) -> bool: ...
                        def ClearField(self, field_name: Literal["message6", b"message6"]) -> None: ...

                    KEY_FIELD_NUMBER: int
                    VALUE_FIELD_NUMBER: int
                    key: str
                    @property
                    def value(self) -> GetHomeGraphResponse.Home.Device.Message20.Message1.Value: ...
                    def __init__(
                        self,
                        *,
                        key: str = ...,
                        value: GetHomeGraphResponse.Home.Device.Message20.Message1.Value | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: Literal["value", b"value"]) -> bool: ...
                    def ClearField(self, field_name: Literal["key", b"key", "value", b"value"]) -> None: ...

                MESSAGE1_FIELD_NUMBER: int
                @property
                def message1(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Device.Message20.Message1]: ...
                def __init__(
                    self,
                    *,
                    message1: Iterable[GetHomeGraphResponse.Home.Device.Message20.Message1] | None = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["message1", b"message1"]) -> None: ...

            @final
            class Message25(Message):
                DESCRIPTOR: Descriptor

                BOOL1_FIELD_NUMBER: int
                BOOL2_FIELD_NUMBER: int
                bool1: bool
                bool2: bool
                def __init__(
                    self,
                    *,
                    bool1: bool = ...,
                    bool2: bool = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["bool1", b"bool1", "bool2", b"bool2"]) -> None: ...

            @final
            class LinkedUser(Message):
                DESCRIPTOR: Descriptor

                EMAIL_ADDRESS_FIELD_NUMBER: int
                email_address: str
                def __init__(
                    self,
                    *,
                    email_address: str = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["email_address", b"email_address"]) -> None: ...

            @final
            class State(Message):
                DESCRIPTOR: Descriptor

                NAME_FIELD_NUMBER: int
                VALUE_FIELD_NUMBER: int
                name: str
                value: bytes
                def __init__(
                    self,
                    *,
                    name: str = ...,
                    value: bytes = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["name", b"name", "value", b"value"]) -> None: ...

            @final
            class Message30(Message):
                DESCRIPTOR: Descriptor

                @final
                class Message2(Message):
                    DESCRIPTOR: Descriptor

                    @final
                    class Message2(Message):
                        DESCRIPTOR: Descriptor

                        BOOL4_FIELD_NUMBER: int
                        bool4: bool
                        def __init__(
                            self,
                            *,
                            bool4: bool = ...,
                        ) -> None: ...
                        def ClearField(self, field_name: Literal["bool4", b"bool4"]) -> None: ...

                    STRING1_FIELD_NUMBER: int
                    MESSAGE2_FIELD_NUMBER: int
                    string1: str
                    @property
                    def message2(self) -> GetHomeGraphResponse.Home.Device.Message30.Message2.Message2: ...
                    def __init__(
                        self,
                        *,
                        string1: str = ...,
                        message2: GetHomeGraphResponse.Home.Device.Message30.Message2.Message2 | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: Literal["message2", b"message2"]) -> bool: ...
                    def ClearField(self, field_name: Literal["message2", b"message2", "string1", b"string1"]) -> None: ...

                KEY_FIELD_NUMBER: int
                MESSAGE2_FIELD_NUMBER: int
                key: str
                @property
                def message2(self) -> GetHomeGraphResponse.Home.Device.Message30.Message2: ...
                def __init__(
                    self,
                    *,
                    key: str = ...,
                    message2: GetHomeGraphResponse.Home.Device.Message30.Message2 | None = ...,
                ) -> None: ...
                def HasField(self, field_name: Literal["message2", b"message2"]) -> bool: ...
                def ClearField(self, field_name: Literal["key", b"key", "message2", b"message2"]) -> None: ...

            @final
            class Message34(Message):
                DESCRIPTOR: Descriptor

                BOOL1_FIELD_NUMBER: int
                bool1: bool
                def __init__(
                    self,
                    *,
                    bool1: bool = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["bool1", b"bool1"]) -> None: ...

            DEVICE_INFO_FIELD_NUMBER: int
            DEVICE_NAME_FIELD_NUMBER: int
            DEVICE_TYPE_FIELD_NUMBER: int
            TRAITS_FIELD_NUMBER: int
            SUFFIX_FIELD_NUMBER: int
            MESSAGE12_FIELD_NUMBER: int
            MESSAGE15_FIELD_NUMBER: int
            HARDWARE_FIELD_NUMBER: int
            MESSAGE18_FIELD_NUMBER: int
            TIMESTAMP19_FIELD_NUMBER: int
            MESSAGE20_FIELD_NUMBER: int
            MESSAGE25_FIELD_NUMBER: int
            LINKED_USERS_FIELD_NUMBER: int
            LOCAL_AUTH_TOKEN_FIELD_NUMBER: int
            STATES_FIELD_NUMBER: int
            MESSAGE30_FIELD_NUMBER: int
            MESSAGE34_FIELD_NUMBER: int
            NUM37_FIELD_NUMBER: int
            STRING41_FIELD_NUMBER: int
            STRING42_FIELD_NUMBER: int
            device_name: str
            device_type: str
            suffix: str
            timestamp19: int
            local_auth_token: str
            num37: int
            string41: str
            string42: str
            @property
            def device_info(self) -> GetHomeGraphResponse.Home.Device.DeviceInfo: ...
            @property
            def traits(self) -> RepeatedScalarFieldContainer[str]: ...
            @property
            def message12(self) -> GetHomeGraphResponse.Home.Device.Message12: ...
            @property
            def message15(self) -> GetHomeGraphResponse.Home.Device.Message15: ...
            @property
            def hardware(self) -> GetHomeGraphResponse.Home.Device.Hardware: ...
            @property
            def message18(self) -> GetHomeGraphResponse.Home.Device.Message18: ...
            @property
            def message20(self) -> GetHomeGraphResponse.Home.Device.Message20: ...
            @property
            def message25(self) -> GetHomeGraphResponse.Home.Device.Message25: ...
            @property
            def linked_users(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Device.LinkedUser]: ...
            @property
            def states(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Device.State]: ...
            @property
            def message30(self) -> GetHomeGraphResponse.Home.Device.Message30: ...
            @property
            def message34(self) -> GetHomeGraphResponse.Home.Device.Message34: ...
            def __init__(
                self,
                *,
                device_info: GetHomeGraphResponse.Home.Device.DeviceInfo | None = ...,
                device_name: str = ...,
                device_type: str = ...,
                traits: Iterable[str] | None = ...,
                suffix: str = ...,
                message12: GetHomeGraphResponse.Home.Device.Message12 | None = ...,
                message15: GetHomeGraphResponse.Home.Device.Message15 | None = ...,
                hardware: GetHomeGraphResponse.Home.Device.Hardware | None = ...,
                message18: GetHomeGraphResponse.Home.Device.Message18 | None = ...,
                timestamp19: int = ...,
                message20: GetHomeGraphResponse.Home.Device.Message20 | None = ...,
                message25: GetHomeGraphResponse.Home.Device.Message25 | None = ...,
                linked_users: Iterable[GetHomeGraphResponse.Home.Device.LinkedUser] | None = ...,
                local_auth_token: str = ...,
                states: Iterable[GetHomeGraphResponse.Home.Device.State] | None = ...,
                message30: GetHomeGraphResponse.Home.Device.Message30 | None = ...,
                message34: GetHomeGraphResponse.Home.Device.Message34 | None = ...,
                num37: int = ...,
                string41: str = ...,
                string42: str = ...,
            ) -> None: ...
            def HasField(self, field_name: Literal["device_info", b"device_info", "hardware", b"hardware", "message12", b"message12", "message15", b"message15", "message18", b"message18", "message20", b"message20", "message25", b"message25", "message30", b"message30", "message34", b"message34"]) -> bool: ...
            def ClearField(self, field_name: Literal["device_info", b"device_info", "device_name", b"device_name", "device_type", b"device_type", "hardware", b"hardware", "linked_users", b"linked_users", "local_auth_token", b"local_auth_token", "message12", b"message12", "message15", b"message15", "message18", b"message18", "message20", b"message20", "message25", b"message25", "message30", b"message30", "message34", b"message34", "num37", b"num37", "states", b"states", "string41", b"string41", "string42", b"string42", "suffix", b"suffix", "timestamp19", b"timestamp19", "traits", b"traits"]) -> None: ...

        @final
        class Message11(Message):
            DESCRIPTOR: Descriptor

            BOOL1_FIELD_NUMBER: int
            bool1: bool
            def __init__(
                self,
                *,
                bool1: bool = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["bool1", b"bool1"]) -> None: ...

        @final
        class Message13(Message):
            DESCRIPTOR: Descriptor

            @final
            class Message1(Message):
                DESCRIPTOR: Descriptor

                @final
                class DeviceInfo(Message):
                    DESCRIPTOR: Descriptor

                    @final
                    class AgentInfo(Message):
                        DESCRIPTOR: Descriptor

                        API_PROJECT_ID_FIELD_NUMBER: int
                        UNIQUE_ID_FIELD_NUMBER: int
                        api_project_id: str
                        unique_id: str
                        def __init__(
                            self,
                            *,
                            api_project_id: str = ...,
                            unique_id: str = ...,
                        ) -> None: ...
                        def ClearField(self, field_name: Literal["api_project_id", b"api_project_id", "unique_id", b"unique_id"]) -> None: ...

                    DEVICE_ID_FIELD_NUMBER: int
                    AGENT_INFO_FIELD_NUMBER: int
                    device_id: str
                    @property
                    def agent_info(self) -> GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo.AgentInfo: ...
                    def __init__(
                        self,
                        *,
                        device_id: str = ...,
                        agent_info: GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo.AgentInfo | None = ...,
                    ) -> None: ...
                    def HasField(self, field_name: Literal["agent_info", b"agent_info"]) -> bool: ...
                    def ClearField(self, field_name: Literal["agent_info", b"agent_info", "device_id", b"device_id"]) -> None: ...

                DEVICE_INFO_FIELD_NUMBER: int
                @property
                def device_info(self) -> GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo: ...
                def __init__(
                    self,
                    *,
                    device_info: GetHomeGraphResponse.Home.Message13.Message1.DeviceInfo | None = ...,
                ) -> None: ...
                def HasField(self, field_name: Literal["device_info", b"device_info"]) -> bool: ...
                def ClearField(self, field_name: Literal["device_info", b"device_info"]) -> None: ...

            MESSAGE1_FIELD_NUMBER: int
            DUO_CALL_URL_FIELD_NUMBER: int
            DUO_PHONE_NUMBER_FIELD_NUMBER: int
            duo_call_url: str
            duo_phone_number: str
            @property
            def message1(self) -> GetHomeGraphResponse.Home.Message13.Message1: ...
            def __init__(
                self,
                *,
                message1: GetHomeGraphResponse.Home.Message13.Message1 | None = ...,
                duo_call_url: str = ...,
                duo_phone_number: str = ...,
            ) -> None: ...
            def HasField(self, field_name: Literal["message1", b"message1"]) -> bool: ...
            def ClearField(self, field_name: Literal["duo_call_url", b"duo_call_url", "duo_phone_number", b"duo_phone_number", "message1", b"message1"]) -> None: ...

        @final
        class Message15(Message):
            DESCRIPTOR: Descriptor

            @final
            class Message3(Message):
                DESCRIPTOR: Descriptor

                @final
                class Message2(Message):
                    DESCRIPTOR: Descriptor

                    STRING1_FIELD_NUMBER: int
                    string1: str
                    def __init__(
                        self,
                        *,
                        string1: str = ...,
                    ) -> None: ...
                    def ClearField(self, field_name: Literal["string1", b"string1"]) -> None: ...

                STRING1_FIELD_NUMBER: int
                MESSAGE2_FIELD_NUMBER: int
                string1: str
                @property
                def message2(self) -> GetHomeGraphResponse.Home.Message15.Message3.Message2: ...
                def __init__(
                    self,
                    *,
                    string1: str = ...,
                    message2: GetHomeGraphResponse.Home.Message15.Message3.Message2 | None = ...,
                ) -> None: ...
                def HasField(self, field_name: Literal["message2", b"message2"]) -> bool: ...
                def ClearField(self, field_name: Literal["message2", b"message2", "string1", b"string1"]) -> None: ...

            BOOL1_FIELD_NUMBER: int
            STRING2_FIELD_NUMBER: int
            MESSAGE3_FIELD_NUMBER: int
            BOOL4_FIELD_NUMBER: int
            bool1: bool
            string2: str
            bool4: bool
            @property
            def message3(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Message15.Message3]: ...
            def __init__(
                self,
                *,
                bool1: bool = ...,
                string2: str = ...,
                message3: Iterable[GetHomeGraphResponse.Home.Message15.Message3] | None = ...,
                bool4: bool = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["bool1", b"bool1", "bool4", b"bool4", "message3", b"message3", "string2", b"string2"]) -> None: ...

        HOME_ID_FIELD_NUMBER: int
        HOME_NAME_FIELD_NUMBER: int
        LOCATION_FIELD_NUMBER: int
        LINKED_USERS_FIELD_NUMBER: int
        ROOMS_FIELD_NUMBER: int
        DEVICES_FIELD_NUMBER: int
        MESSAGE11_FIELD_NUMBER: int
        STRING12_FIELD_NUMBER: int
        MESSAGE13_FIELD_NUMBER: int
        MESSAGE14_FIELD_NUMBER: int
        MESSAGE15_FIELD_NUMBER: int
        home_id: str
        home_name: str
        string12: str
        message14: str
        @property
        def location(self) -> GetHomeGraphResponse.Home.Location: ...
        @property
        def linked_users(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.LinkedUser]: ...
        @property
        def rooms(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Room]: ...
        @property
        def devices(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Home.Device]: ...
        @property
        def message11(self) -> GetHomeGraphResponse.Home.Message11: ...
        @property
        def message13(self) -> GetHomeGraphResponse.Home.Message13: ...
        @property
        def message15(self) -> GetHomeGraphResponse.Home.Message15: ...
        def __init__(
            self,
            *,
            home_id: str = ...,
            home_name: str = ...,
            location: GetHomeGraphResponse.Home.Location | None = ...,
            linked_users: Iterable[GetHomeGraphResponse.Home.LinkedUser] | None = ...,
            rooms: Iterable[GetHomeGraphResponse.Home.Room] | None = ...,
            devices: Iterable[GetHomeGraphResponse.Home.Device] | None = ...,
            message11: GetHomeGraphResponse.Home.Message11 | None = ...,
            string12: str = ...,
            message13: GetHomeGraphResponse.Home.Message13 | None = ...,
            message14: str = ...,
            message15: GetHomeGraphResponse.Home.Message15 | None = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["location", b"location", "message11", b"message11", "message13", b"message13", "message15", b"message15"]) -> bool: ...
        def ClearField(self, field_name: Literal["devices", b"devices", "home_id", b"home_id", "home_name", b"home_name", "linked_users", b"linked_users", "location", b"location", "message11", b"message11", "message13", b"message13", "message14", b"message14", "message15", b"message15", "rooms", b"rooms", "string12", b"string12"]) -> None: ...

    @final
    class Group(Message):
        DESCRIPTOR: Descriptor

        @final
        class DeviceInfo(Message):
            DESCRIPTOR: Descriptor

            @final
            class AgentInfo(Message):
                DESCRIPTOR: Descriptor

                API_PROJECT_ID_FIELD_NUMBER: int
                UNIQUE_ID_FIELD_NUMBER: int
                api_project_id: str
                unique_id: str
                def __init__(
                    self,
                    *,
                    api_project_id: str = ...,
                    unique_id: str = ...,
                ) -> None: ...
                def ClearField(self, field_name: Literal["api_project_id", b"api_project_id", "unique_id", b"unique_id"]) -> None: ...

            AGENT_INFO_FIELD_NUMBER: int
            @property
            def agent_info(self) -> GetHomeGraphResponse.Group.DeviceInfo.AgentInfo: ...
            def __init__(
                self,
                *,
                agent_info: GetHomeGraphResponse.Group.DeviceInfo.AgentInfo | None = ...,
            ) -> None: ...
            def HasField(self, field_name: Literal["agent_info", b"agent_info"]) -> bool: ...
            def ClearField(self, field_name: Literal["agent_info", b"agent_info"]) -> None: ...

        @final
        class Message12(Message):
            DESCRIPTOR: Descriptor

            BOOL3_FIELD_NUMBER: int
            BOOL4_FIELD_NUMBER: int
            BOOL37_FIELD_NUMBER: int
            BOOL38_FIELD_NUMBER: int
            bool3: bool
            bool4: bool
            bool37: bool
            bool38: bool
            def __init__(
                self,
                *,
                bool3: bool = ...,
                bool4: bool = ...,
                bool37: bool = ...,
                bool38: bool = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["bool3", b"bool3", "bool37", b"bool37", "bool38", b"bool38", "bool4", b"bool4"]) -> None: ...

        @final
        class Message15(Message):
            DESCRIPTOR: Descriptor

            STRING1_FIELD_NUMBER: int
            NUM5_FIELD_NUMBER: int
            NUM6_FIELD_NUMBER: int
            string1: str
            num5: int
            num6: int
            def __init__(
                self,
                *,
                string1: str = ...,
                num5: int = ...,
                num6: int = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["num5", b"num5", "num6", b"num6", "string1", b"string1"]) -> None: ...

        @final
        class Message17(Message):
            DESCRIPTOR: Descriptor

            GROUP_MODEL_FIELD_NUMBER: int
            group_model: str
            def __init__(
                self,
                *,
                group_model: str = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["group_model", b"group_model"]) -> None: ...

        @final
        class Message18(Message):
            DESCRIPTOR: Descriptor

            GROUP_NAME_FIELD_NUMBER: int
            group_name: str
            def __init__(
                self,
                *,
                group_name: str = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["group_name", b"group_name"]) -> None: ...

        @final
        class Message34(Message):
            DESCRIPTOR: Descriptor

            BOOL1_FIELD_NUMBER: int
            bool1: bool
            def __init__(
                self,
                *,
                bool1: bool = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["bool1", b"bool1"]) -> None: ...

        DEVICE_INFO_FIELD_NUMBER: int
        GROUP_NMAE_FIELD_NUMBER: int
        DEVICE_TYPE_FIELD_NUMBER: int
        TRAITS_FIELD_NUMBER: int
        SUFFIX_FIELD_NUMBER: int
        MESSAGE12_FIELD_NUMBER: int
        MESSAGE15_FIELD_NUMBER: int
        MESSAGE17_FIELD_NUMBER: int
        MESSAGE18_FIELD_NUMBER: int
        TIMESTAMP19_FIELD_NUMBER: int
        MESSAGE34_FIELD_NUMBER: int
        group_nmae: str
        device_type: str
        traits: str
        suffix: str
        timestamp19: int
        @property
        def device_info(self) -> GetHomeGraphResponse.Group.DeviceInfo: ...
        @property
        def message12(self) -> GetHomeGraphResponse.Group.Message12: ...
        @property
        def message15(self) -> GetHomeGraphResponse.Group.Message15: ...
        @property
        def message17(self) -> GetHomeGraphResponse.Group.Message17: ...
        @property
        def message18(self) -> GetHomeGraphResponse.Group.Message18: ...
        @property
        def message34(self) -> GetHomeGraphResponse.Group.Message34: ...
        def __init__(
            self,
            *,
            device_info: GetHomeGraphResponse.Group.DeviceInfo | None = ...,
            group_nmae: str = ...,
            device_type: str = ...,
            traits: str = ...,
            suffix: str = ...,
            message12: GetHomeGraphResponse.Group.Message12 | None = ...,
            message15: GetHomeGraphResponse.Group.Message15 | None = ...,
            message17: GetHomeGraphResponse.Group.Message17 | None = ...,
            message18: GetHomeGraphResponse.Group.Message18 | None = ...,
            timestamp19: int = ...,
            message34: GetHomeGraphResponse.Group.Message34 | None = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["device_info", b"device_info", "message12", b"message12", "message15", b"message15", "message17", b"message17", "message18", b"message18", "message34", b"message34"]) -> bool: ...
        def ClearField(self, field_name: Literal["device_info", b"device_info", "device_type", b"device_type", "group_nmae", b"group_nmae", "message12", b"message12", "message15", b"message15", "message17", b"message17", "message18", b"message18", "message34", b"message34", "suffix", b"suffix", "timestamp19", b"timestamp19", "traits", b"traits"]) -> None: ...

    @final
    class RoomType(Message):
        DESCRIPTOR: Descriptor

        CODE_FIELD_NUMBER: int
        NAME_FIELD_NUMBER: int
        code: str
        name: str
        def __init__(
            self,
            *,
            code: str = ...,
            name: str = ...,
        ) -> None: ...
        def ClearField(self, field_name: Literal["code", b"code", "name", b"name"]) -> None: ...

    @final
    class DeviceType(Message):
        DESCRIPTOR: Descriptor

        CODE_FIELD_NUMBER: int
        NAME_FIELD_NUMBER: int
        code: str
        name: str
        def __init__(
            self,
            *,
            code: str = ...,
            name: str = ...,
        ) -> None: ...
        def ClearField(self, field_name: Literal["code", b"code", "name", b"name"]) -> None: ...

    @final
    class ProjectType(Message):
        DESCRIPTOR: Descriptor

        CODE_FIELD_NUMBER: int
        NAME_FIELD_NUMBER: int
        code: str
        name: str
        def __init__(
            self,
            *,
            code: str = ...,
            name: str = ...,
        ) -> None: ...
        def ClearField(self, field_name: Literal["code", b"code", "name", b"name"]) -> None: ...

    @final
    class Message11(Message):
        DESCRIPTOR: Descriptor

        @final
        class Message2(Message):
            DESCRIPTOR: Descriptor

            NUM2_FIELD_NUMBER: int
            num2: int
            def __init__(
                self,
                *,
                num2: int = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["num2", b"num2"]) -> None: ...

        NAME_FIELD_NUMBER: int
        MESSAGE2_FIELD_NUMBER: int
        name: str
        @property
        def message2(self) -> GetHomeGraphResponse.Message11.Message2: ...
        def __init__(
            self,
            *,
            name: str = ...,
            message2: GetHomeGraphResponse.Message11.Message2 | None = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["message2", b"message2"]) -> bool: ...
        def ClearField(self, field_name: Literal["message2", b"message2", "name", b"name"]) -> None: ...

    @final
    class LinkedApp(Message):
        DESCRIPTOR: Descriptor

        STRING1_FIELD_NUMBER: int
        STRING2_FIELD_NUMBER: int
        NUM3_FIELD_NUMBER: int
        NUM4_FIELD_NUMBER: int
        NUM5_FIELD_NUMBER: int
        string1: str
        string2: str
        num3: int
        num4: int
        num5: int
        def __init__(
            self,
            *,
            string1: str = ...,
            string2: str = ...,
            num3: int = ...,
            num4: int = ...,
            num5: int = ...,
        ) -> None: ...
        def ClearField(self, field_name: Literal["num3", b"num3", "num4", b"num4", "num5", b"num5", "string1", b"string1", "string2", b"string2"]) -> None: ...

    TIMESTAMP1_FIELD_NUMBER: int
    HOME_FIELD_NUMBER: int
    GROUPS_FIELD_NUMBER: int
    ROOM_TYPES_FIELD_NUMBER: int
    STRING5_FIELD_NUMBER: int
    BOOL6_FIELD_NUMBER: int
    DEVICE_TYPES_FIELD_NUMBER: int
    PROJECT_TYPES_FIELD_NUMBER: int
    MESSAGE11_FIELD_NUMBER: int
    LINKED_APPS_FIELD_NUMBER: int
    timestamp1: int
    string5: str
    bool6: bool
    @property
    def home(self) -> GetHomeGraphResponse.Home: ...
    @property
    def groups(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Group]: ...
    @property
    def room_types(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.RoomType]: ...
    @property
    def device_types(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.DeviceType]: ...
    @property
    def project_types(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.ProjectType]: ...
    @property
    def message11(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.Message11]: ...
    @property
    def linked_apps(self) -> RepeatedCompositeFieldContainer[GetHomeGraphResponse.LinkedApp]: ...
    def __init__(
        self,
        *,
        timestamp1: int = ...,
        home: GetHomeGraphResponse.Home | None = ...,
        groups: Iterable[GetHomeGraphResponse.Group] | None = ...,
        room_types: Iterable[GetHomeGraphResponse.RoomType] | None = ...,
        string5: str = ...,
        bool6: bool = ...,
        device_types: Iterable[GetHomeGraphResponse.DeviceType] | None = ...,
        project_types: Iterable[GetHomeGraphResponse.ProjectType] | None = ...,
        message11: Iterable[GetHomeGraphResponse.Message11] | None = ...,
        linked_apps: Iterable[GetHomeGraphResponse.LinkedApp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["home", b"home"]) -> bool: ...
    def ClearField(self, field_name: Literal["bool6", b"bool6", "device_types", b"device_types", "groups", b"groups", "home", b"home", "linked_apps", b"linked_apps", "message11", b"message11", "project_types", b"project_types", "room_types", b"room_types", "string5", b"string5", "timestamp1", b"timestamp1"]) -> None: ...

@final
class GetAssistantDeviceSettingsRequest(Message):
    DESCRIPTOR: Descriptor

    @final
    class DeviceInfo(Message):
        DESCRIPTOR: Descriptor

        @final
        class AgentInfo(Message):
            DESCRIPTOR: Descriptor

            API_PROJECT_ID_FIELD_NUMBER: int
            UNIQUE_ID_FIELD_NUMBER: int
            api_project_id: str
            unique_id: str
            def __init__(
                self,
                *,
                api_project_id: str = ...,
                unique_id: str = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["api_project_id", b"api_project_id", "unique_id", b"unique_id"]) -> None: ...

        DEVICE_ID_FIELD_NUMBER: int
        AGENT_INFO_FIELD_NUMBER: int
        device_id: str
        @property
        def agent_info(self) -> GetAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo: ...
        def __init__(
            self,
            *,
            device_id: str = ...,
            agent_info: GetAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["agent_info", b"agent_info"]) -> bool: ...
        def ClearField(self, field_name: Literal["agent_info", b"agent_info", "device_id", b"device_id"]) -> None: ...

    DEVICE_INFO_FIELD_NUMBER: int
    STRING2_FIELD_NUMBER: int
    string2: str
    @property
    def device_info(self) -> GetAssistantDeviceSettingsRequest.DeviceInfo: ...
    def __init__(
        self,
        *,
        device_info: GetAssistantDeviceSettingsRequest.DeviceInfo | None = ...,
        string2: str = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["device_info", b"device_info"]) -> bool: ...
    def ClearField(self, field_name: Literal["device_info", b"device_info", "string2", b"string2"]) -> None: ...

@final
class GetAssistantDeviceSettingsResponse(Message):
    DESCRIPTOR: Descriptor

    @final
    class Message1(Message):
        DESCRIPTOR: Descriptor

        NUM1_FIELD_NUMBER: int
        NUM2_FIELD_NUMBER: int
        NUM4_FIELD_NUMBER: int
        NUM5_FIELD_NUMBER: int
        NUM6_FIELD_NUMBER: int
        STRING10_FIELD_NUMBER: int
        num1: int
        num2: int
        num4: int
        num5: int
        num6: int
        string10: str
        def __init__(
            self,
            *,
            num1: int = ...,
            num2: int = ...,
            num4: int = ...,
            num5: int = ...,
            num6: int = ...,
            string10: str = ...,
        ) -> None: ...
        def ClearField(self, field_name: Literal["num1", b"num1", "num2", b"num2", "num4", b"num4", "num5", b"num5", "num6", b"num6", "string10", b"string10"]) -> None: ...

    MESSAGE1_FIELD_NUMBER: int
    @property
    def message1(self) -> GetAssistantDeviceSettingsResponse.Message1: ...
    def __init__(
        self,
        *,
        message1: GetAssistantDeviceSettingsResponse.Message1 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["message1", b"message1"]) -> bool: ...
    def ClearField(self, field_name: Literal["message1", b"message1"]) -> None: ...

@final
class UpdateAssistantDeviceSettingsRequest(Message):
    DESCRIPTOR: Descriptor

    @final
    class DeviceInfo(Message):
        DESCRIPTOR: Descriptor

        @final
        class AgentInfo(Message):
            DESCRIPTOR: Descriptor

            API_PROJECT_ID_FIELD_NUMBER: int
            UNIQUE_ID_FIELD_NUMBER: int
            api_project_id: str
            unique_id: str
            def __init__(
                self,
                *,
                api_project_id: str = ...,
                unique_id: str = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["api_project_id", b"api_project_id", "unique_id", b"unique_id"]) -> None: ...

        DEVICE_ID_FIELD_NUMBER: int
        AGENT_INFO_FIELD_NUMBER: int
        device_id: str
        @property
        def agent_info(self) -> UpdateAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo: ...
        def __init__(
            self,
            *,
            device_id: str = ...,
            agent_info: UpdateAssistantDeviceSettingsRequest.DeviceInfo.AgentInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["agent_info", b"agent_info"]) -> bool: ...
        def ClearField(self, field_name: Literal["agent_info", b"agent_info", "device_id", b"device_id"]) -> None: ...

    @final
    class UpdateData(Message):
        DESCRIPTOR: Descriptor

        @final
        class Message1(Message):
            DESCRIPTOR: Descriptor

            YOUTUBE_RESTRICTED_MODE_FIELD_NUMBER: int
            YOUTUBE_TV_CONTENT_FILTER_FIELD_NUMBER: int
            LOCALE_FIELD_NUMBER: int
            youtube_restricted_mode: int
            """1=off, 2=on"""
            youtube_tv_content_filter: int
            """1=off, 2=on"""
            locale: str
            """local like "en-US" """
            def __init__(
                self,
                *,
                youtube_restricted_mode: int = ...,
                youtube_tv_content_filter: int = ...,
                locale: str = ...,
            ) -> None: ...
            def ClearField(self, field_name: Literal["locale", b"locale", "youtube_restricted_mode", b"youtube_restricted_mode", "youtube_tv_content_filter", b"youtube_tv_content_filter"]) -> None: ...

        MESSAGE1_FIELD_NUMBER: int
        @property
        def message1(self) -> UpdateAssistantDeviceSettingsRequest.UpdateData.Message1: ...
        def __init__(
            self,
            *,
            message1: UpdateAssistantDeviceSettingsRequest.UpdateData.Message1 | None = ...,
        ) -> None: ...
        def HasField(self, field_name: Literal["message1", b"message1"]) -> bool: ...
        def ClearField(self, field_name: Literal["message1", b"message1"]) -> None: ...

    STRING1_FIELD_NUMBER: int
    DEVICE_INFO_FIELD_NUMBER: int
    UPDATE_DATA_FIELD_NUMBER: int
    string1: str
    @property
    def device_info(self) -> UpdateAssistantDeviceSettingsRequest.DeviceInfo: ...
    @property
    def update_data(self) -> UpdateAssistantDeviceSettingsRequest.UpdateData: ...
    def __init__(
        self,
        *,
        string1: str = ...,
        device_info: UpdateAssistantDeviceSettingsRequest.DeviceInfo | None = ...,
        update_data: UpdateAssistantDeviceSettingsRequest.UpdateData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: Literal["device_info", b"device_info", "update_data", b"update_data"]) -> bool: ...
    def ClearField(self, field_name: Literal["device_info", b"device_info", "string1", b"string1", "update_data", b"update_data"]) -> None: ...

@final
class UpdateAssistantDeviceSettingsResponse(Message):
    DESCRIPTOR: Descriptor

    STRING1_FIELD_NUMBER: int
    string1: str
    def __init__(
        self,
        *,
        string1: str = ...,
    ) -> None: ...
    def ClearField(self, field_name: Literal["string1", b"string1"]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""

from __future__ import annotations

import grpc

from ghome_foyer_api import api_pb2 as ghome__foyer__api_dot_api__pb2

GRPC_GENERATED_VERSION = "1.71.0"
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower

    _version_not_supported = first_version_is_lower(
        GRPC_VERSION, GRPC_GENERATED_VERSION
    )
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f"The grpc package installed is at version {GRPC_VERSION},"
        + f" but the generated code in ghome_foyer_api/api_pb2_grpc.py depends on"
        + f" grpcio>={GRPC_GENERATED_VERSION}."
        + f" Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}"
        + f" or downgrade your generated code using grpcio-tools<={GRPC_VERSION}."
    )


class HomeControlServiceStub:
    """Home Control Service"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAssistantRoutines = channel.unary_stream(
            "/google.internal.home.foyer.v1.HomeControlService/GetAssistantRoutines",
            request_serializer=ghome__foyer__api_dot_api__pb2.GetAssistantRoutinesRequest.SerializeToString,
            response_deserializer=ghome__foyer__api_dot_api__pb2.GetAssistantRoutinesResponse.FromString,
            _registered_method=True,
        )


class HomeControlServiceServicer:
    """Home Control Service"""

    def GetAssistantRoutines(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HomeControlServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetAssistantRoutines": grpc.unary_stream_rpc_method_handler(
            servicer.GetAssistantRoutines,
            request_deserializer=ghome__foyer__api_dot_api__pb2.GetAssistantRoutinesRequest.FromString,
            response_serializer=ghome__foyer__api_dot_api__pb2.GetAssistantRoutinesResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.internal.home.foyer.v1.HomeControlService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "google.internal.home.foyer.v1.HomeControlService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class HomeControlService:
    """Home Control Service"""

    @staticmethod
    def GetAssistantRoutines(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/google.internal.home.foyer.v1.HomeControlService/GetAssistantRoutines",
            ghome__foyer__api_dot_api__pb2.GetAssistantRoutinesRequest.SerializeToString,
            ghome__foyer__api_dot_api__pb2.GetAssistantRoutinesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )


class StructuresServiceStub:
    """Structure Service"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetHomeGraph = channel.unary_unary(
            "/google.internal.home.foyer.v1.StructuresService/GetHomeGraph",
            request_serializer=ghome__foyer__api_dot_api__pb2.GetHomeGraphRequest.SerializeToString,
            response_deserializer=ghome__foyer__api_dot_api__pb2.GetHomeGraphResponse.FromString,
            _registered_method=True,
        )


class StructuresServiceServicer:
    """Structure Service"""

    def GetHomeGraph(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_StructuresServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetHomeGraph": grpc.unary_unary_rpc_method_handler(
            servicer.GetHomeGraph,
            request_deserializer=ghome__foyer__api_dot_api__pb2.GetHomeGraphRequest.FromString,
            response_serializer=ghome__foyer__api_dot_api__pb2.GetHomeGraphResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.internal.home.foyer.v1.StructuresService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "google.internal.home.foyer.v1.StructuresService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class StructuresService:
    """Structure Service"""

    @staticmethod
    def GetHomeGraph(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.internal.home.foyer.v1.StructuresService/GetHomeGraph",
            ghome__foyer__api_dot_api__pb2.GetHomeGraphRequest.SerializeToString,
            ghome__foyer__api_dot_api__pb2.GetHomeGraphResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )


class HomeDevicesServiceStub:
    """Home Devices Service"""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAssistantDeviceSettings = channel.unary_stream(
            "/google.internal.home.foyer.v1.HomeDevicesService/GetAssistantDeviceSettings",
            request_serializer=ghome__foyer__api_dot_api__pb2.GetAssistantDeviceSettingsRequest.SerializeToString,
            response_deserializer=ghome__foyer__api_dot_api__pb2.GetAssistantDeviceSettingsResponse.FromString,
            _registered_method=True,
        )
        self.UpdateAssistantDeviceSettings = channel.unary_stream(
            "/google.internal.home.foyer.v1.HomeDevicesService/UpdateAssistantDeviceSettings",
            request_serializer=ghome__foyer__api_dot_api__pb2.UpdateAssistantDeviceSettingsRequest.SerializeToString,
            response_deserializer=ghome__foyer__api_dot_api__pb2.UpdateAssistantDeviceSettingsResponse.FromString,
            _registered_method=True,
        )


class HomeDevicesServiceServicer:
    """Home Devices Service"""

    def GetAssistantDeviceSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateAssistantDeviceSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_HomeDevicesServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetAssistantDeviceSettings": grpc.unary_stream_rpc_method_handler(
            servicer.GetAssistantDeviceSettings,
            request_deserializer=ghome__foyer__api_dot_api__pb2.GetAssistantDeviceSettingsRequest.FromString,
            response_serializer=ghome__foyer__api_dot_api__pb2.GetAssistantDeviceSettingsResponse.SerializeToString,
        ),
        "UpdateAssistantDeviceSettings": grpc.unary_stream_rpc_method_handler(
            servicer.UpdateAssistantDeviceSettings,
            request_deserializer=ghome__foyer__api_dot_api__pb2.UpdateAssistantDeviceSettingsRequest.FromString,
            response_serializer=ghome__foyer__api_dot_api__pb2.UpdateAssistantDeviceSettingsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.internal.home.foyer.v1.HomeDevicesService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers(
        "google.internal.home.foyer.v1.HomeDevicesService", rpc_method_handlers
    )


# This class is part of an EXPERIMENTAL API.
class HomeDevicesService:
    """Home Devices Service"""

    @staticmethod
    def GetAssistantDeviceSettings(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/google.internal.home.foyer.v1.HomeDevicesService/GetAssistantDeviceSettings",
            ghome__foyer__api_dot_api__pb2.GetAssistantDeviceSettingsRequest.SerializeToString,
            ghome__foyer__api_dot_api__pb2.GetAssistantDeviceSettingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )

    @staticmethod
    def UpdateAssistantDeviceSettings(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_stream(
            request,
            target,
            "/google.internal.home.foyer.v1.HomeDevicesService/UpdateAssistantDeviceSettings",
            ghome__foyer__api_dot_api__pb2.UpdateAssistantDeviceSettingsRequest.SerializeToString,
            ghome__foyer__api_dot_api__pb2.UpdateAssistantDeviceSettingsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True,
        )
